@@ -4,9 +4,12 @@ A PEP-0249 compatible driver for interfacing with Wherobots DB.
 """
 
 import logging
-import os
+import platform
 import urllib.parse
 import queue
+from importlib import metadata
+from importlib.metadata import PackageNotFoundError
+
 import requests
 import tenacity
 import threading
@@ -21,9 +24,10 @@ from .constants import (
     DEFAULT_SESSION_WAIT_TIMEOUT_SECONDS,
     MAX_MESSAGE_SIZE,
     PROTOCOL_VERSION,
-    ResultsFormat,
+    AppStatus,
     DataCompression,
     GeometryRepresentation,
+    ResultsFormat,
 )
 from .errors import (
     InterfaceError,
@@ -38,6 +42,18 @@ threadsafety = 1
 paramstyle = "pyformat"
 
 
+def gen_user_agent_header():
+    try:
+        package_version = metadata.version("wherobots-python-dbapi")
+    except PackageNotFoundError:
+        package_version = "unknown"
+    python_version = platform.python_version()
+    system = platform.system().lower()
+    return {
+        "User-Agent": f"wherobots-python-dbapi/{package_version} os/{system} python/{python_version}"
+    }
+
+
 def connect(
     host: str = DEFAULT_ENDPOINT,
     token: str = None,
@@ -46,6 +62,7 @@ def connect(
     region: Region = None,
     wait_timeout: float = DEFAULT_SESSION_WAIT_TIMEOUT_SECONDS,
     read_timeout: float = DEFAULT_READ_TIMEOUT_SECONDS,
+    shutdown_after_inactive_seconds: Union[int, None] = None,
     results_format: Union[ResultsFormat, None] = None,
     data_compression: Union[DataCompression, None] = None,
     geometry_representation: Union[GeometryRepresentation, None] = None,
@@ -55,12 +72,14 @@ def connect(
     if token and api_key:
         raise ValueError("`token` and `api_key` can't be both provided")
 
-    headers = {}
+    headers = gen_user_agent_header()
     if token:
         headers["Authorization"] = f"Bearer {token}"
     elif api_key:
         headers["X-API-Key"] = api_key
 
+    logging.info(headers)
+
     host = host or DEFAULT_ENDPOINT
     runtime = runtime or DEFAULT_RUNTIME
     region = region or DEFAULT_REGION
@@ -81,7 +100,10 @@ def connect(
         resp = requests.post(
             url=f"{host}/sql/session",
             params={"region": region.value},
-            json={"runtimeId": runtime.value},
+            json={
+                "runtimeId": runtime.value,
+                "shutdownAfterInactiveSeconds": shutdown_after_inactive_seconds,
+            },
             headers=headers,
         )
         resp.raise_for_status()
@@ -103,11 +125,11 @@ def connect(
         r = requests.get(session_id_url, headers=headers)
         r.raise_for_status()
         payload = r.json()
-        status = payload.get("status")
+        status = AppStatus(payload.get("status"))
         logging.info(" ... %s", status)
-        if status in ("REQUESTED", "DEPLOYING", "DEPLOYED", "INITIALIZING"):
+        if status.is_starting():
             raise tenacity.TryAgain("SQL Session is not ready yet")
-        elif status == "READY":
+        elif status == AppStatus.READY:
             return payload["appMeta"]["url"]
         else:
             logging.error("SQL session creation failed: %s; should not retry.", status)
@@ -116,6 +138,7 @@ def connect(
     try:
         logging.info("Getting SQL session status from %s ...", session_id_url)
         session_uri = get_session_uri()
+        logging.debug("SQL session URI from app status: %s", session_uri)
     except Exception as e:
         raise InterfaceError("Could not acquire SQL session!", e)
 
@@ -138,11 +161,6 @@ def http_to_ws(uri: str) -> str:
     return str(urllib.parse.urlunparse(parsed))
 
 
-def append_protocol(uri: str, protocol: str) -> str:
-    """Appends the protocol version to the URI."""
-    return urllib.parse.urljoin(os.path.join(uri, ""), protocol)
-
-
 def connect_direct(
     uri: str,
     headers: dict[str, str] = None,
@@ -152,7 +170,7 @@ def connect_direct(
     geometry_representation: Union[GeometryRepresentation, None] = None,
 ) -> Connection:
     q = queue.SimpleQueue()
-    uri_with_protocol = append_protocol(uri, PROTOCOL_VERSION)
+    uri_with_protocol = f"{uri}/{PROTOCOL_VERSION}"
 
     def create_ws_connection():
         try:
